@@ -4,8 +4,9 @@ use lib '../lib';
 use LibUI ':all';
 use LibUI::Window;
 use LibUI::Label;
-Init( { Size => 1024 } ) && die;
+Init() && die;
 my $window = LibUI::Window->new( 'Hi', 320, 100, 0 );
+$window->setMargined(1);
 $window->setChild( LibUI::Label->new('Hello, World!') );
 $window->onClosing(
     sub {
@@ -14,5 +15,6 @@ $window->onClosing(
     },
     undef
 );
+$window->setMargined(1);
 $window->show;
 Main();
